Skip to contents

categorical() defines a baseline-category softmax model for one unordered categorical predictor used inside mi(). It is currently a predictor-model family for impute_model(), not a response family for drmTMB().

Usage

categorical()

Value

A drm_impute_family object.

Details

The first fitted route is fixed-effect and uses the first factor level as the baseline category. Missing predictor values are integrated by exact summation over the unordered levels.

Examples

categorical()
#> $name
#> [1] "categorical"
#> 
#> $family
#> [1] "categorical"
#> 
#> $link
#> [1] "baseline_softmax"
#> 
#> attr(,"class")
#> [1] "drm_impute_family"