Skip to contents

fixef() returns the fixed-effect coefficients for one distributional parameter, or all fixed-effect coefficient blocks when dpar = NULL. It is a mixed-model-friendly alias for coef().

Usage

fixef(object, ...)

# S3 method for class 'drmTMB'
fixef(object, dpar = NULL, ...)

Arguments

object

A drmTMB fit.

...

Reserved for future extractor options.

dpar

Optional distributional parameter name, such as "mu", "sigma", "hu", "rho12", "sd(id)", or "sd_phylo(species)".

Value

A named numeric vector when dpar is supplied, otherwise a named list of coefficient vectors.