Skip to contents

lognormal() defines a one-response positive continuous distribution with formulas for log-location mu and log-scale sigma.

Usage

lognormal()

Value

A drm_family object.

Details

The model is defined on the log response scale: log(y) ~ Normal(mu, sigma^2). The fitted distributional parameter mu is therefore the mean of log(y), not the arithmetic mean of y.

Examples

lognormal()
#> $name
#> [1] "lognormal"
#> 
#> $family
#> [1] "lognormal"
#> 
#> $n_response
#> [1] 1
#> 
#> $dpars
#> [1] "mu"    "sigma"
#> 
#> $links
#>         mu      sigma 
#> "identity"      "log" 
#> 
#> attr(,"class")
#> [1] "drm_family"