weights() returns the row likelihood multipliers used by a fitted
drmTMB model after model-row filtering. These weights multiply
log-likelihood contributions. They are not known sampling variances or known
sampling covariance; use meta_V() for that meta-analytic role.
Usage
# S3 method for class 'drmTMB'
weights(object, ...)
Arguments
- object
A drmTMB fit.
- ...
Reserved for future extractor options.
Value
A numeric vector with one weight per modelled response row, or per
complete response pair for bivariate Gaussian models.
Examples
dat <- data.frame(
y = c(0.2, 0.5, 1.1, 1.4),
x = c(-1, 0, 1, 2),
w = c(1, 1, 0.5, 2)
)
fit <- drmTMB(bf(y ~ x, sigma ~ 1), data = dat, weights = w)
weights(fit)
#> [1] 1.0 1.0 0.5 2.0